import * as helpers from "@/util/helpers"
import * as chai from "chai"
import { AxiosResponse } from 'axios';

chai.should();

describe("# Helpers Unit Tests", () => {
  describe("# praseBlacklist", () => {
    it("should correclty parse the blacklist object into a string that can be used for regex", () => {
      const blacklist = ["test", "another", "final"]
      const parsed = helpers.parseBlacklist(blacklist)
      const testUrl = "https:somehost:someport/api/feedback/final"
      const isMatched = testUrl.match(new RegExp(parsed, "g"))
      // @ts-ignore
      isMatched.should.not.be.null
      parsed.should.equal("test|another|final")
    })
  })
  describe("# parseErrorNotification", () => {
    it("should return html parsed information about the error if existing", () => {
      const response = { data: { someKey: "this is an error message" } }
      const parsed = helpers.parseErrorNotification(response as AxiosResponse)
      parsed.should.equal("<ul><li>this is an error message</li></ul>")
    })
    it("should return html parsed list of all values of data object if existing", () => {
      const response = { 
        data: { 
          someKey: "some debug information",
          someOtherKey: "some error information",
          someFinalKey: "some response stuff"
        } 
      }
      const parsed = helpers.parseErrorNotification(response as AxiosResponse)
      const expected = "<ul><li>some debug information</li><li>some error information</li>" + 
        "<li>some response stuff</li></ul>"
      parsed.should.equal(expected)
    })
    it("should return default message when no error information exists", () => {
      const response = { data: {}, someKey: "test" }
      const parsed = helpers.parseErrorNotification(response as unknown as AxiosResponse)
      parsed.should.equal("There is no useful error data. Please ask the staff for help.")
    })
    it("should give additional information for 404 requests", () => {
      const response = { status: 404, data: { someKey: "Not found." } }
      const parsed = helpers.parseErrorNotification(response as AxiosResponse)
      parsed.should.include("Not found.")
      parsed.should.include("If you experience unusual behaviour, finish all unfinished work and relog." + 
        " If not, this is probably not a critical error.")
    })
  })
})